Struct run_shell::ShellHandle
source · [−]pub struct ShellHandle<T> { /* private fields */ }Implementations
Methods from Deref<Target = JoinHandle<T>>
1.0.0 · sourcepub fn thread(&self) -> &Thread
pub fn thread(&self) -> &Thread
Extracts a handle to the underlying thread.
Examples
use std::thread;
let builder = thread::Builder::new();
let join_handle: thread::JoinHandle<_> = builder.spawn(|| {
// some work here
}).unwrap();
let thread = join_handle.thread();
println!("thread id: {:?}", thread.id());1.61.0 · sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Checks if the associated thread has finished running its main function.
is_finished supports implementing a non-blocking join operation, by checking
is_finished, and calling join if it returns true. This function does not block. To
block while waiting on the thread to finish, use join.
This might return true for a brief moment after the thread’s main
function has returned, but before the thread itself has stopped running.
However, once this returns true, join can be expected
to return quickly, without blocking for any significant amount of time.